# flotilla

Research and data analysis hub for flotilla research and investments. A made up company that I hope to some day make real.

## Guid

### Unit Tests

`python -m unittest discover -p "test_*.py"`

### Build

`python setup.py sdist bdist_wheel`

### Publish

`twine upload dist/*`
